"""
Pretty printing.
"""

import json

from pygments import formatters
from pygments import highlight
from pygments import lexers


def pretty_print(data):
    """
    Pretty prints JSON data.
    :param data: Dict
    :return: None
    """
    formatted_json = json.dumps(data, sort_keys=True, indent=4)
    print(
        highlight(
            str(formatted_json).encode("utf-8"),
            lexers.JsonLexer(),
            formatters.TerminalFormatter(),
        )
    )



"""
Shutterstock CLI
"""
import click


from .images import images

from .videos import videos

from .audio import audio

from .editorial import editorial

from .cv import cv

from .catalog import catalog

from .ai_audio import ai_audio

from .contributors import contributors

from .user import user

from .test import test


@click.group()
def cli():
    """
    For reference information about the endpoints that this CLI calls, see the API reference.
    http://api-reference.shutterstock.com/
    """


cli.add_command(images)

cli.add_command(videos)

cli.add_command(audio)

cli.add_command(editorial)

cli.add_command(cv)

cli.add_command(catalog)

cli.add_command(ai_audio)

cli.add_command(contributors)

cli.add_command(user)

cli.add_command(test)


if __name__ == "__main__":
    cli()



"""
contributors commands.
"""

import json
import click

from .utils.request import delete, get, post, patch


@click.group()
def contributors():
    """
    contributors group.
    """


@click.command()
@click.option("--id", multiple=True, help="One or more contributor IDs", type=str)
def get_contributor_list(**kwargs):
    """
    Get details about multiple contributors
    """

    get(url="/v2/contributors", params=kwargs, json_data=None)


contributors.add_command(get_contributor_list)


@click.command()
@click.argument("contributor-id")
def get_contributor(**kwargs):
    """
    Get details about a single contributor
    """

    get(
        url="/v2/contributors/" + kwargs["contributor_id"] + "",
        params=kwargs,
        json_data=None,
    )


contributors.add_command(get_contributor)


@click.command()
@click.argument("contributor-id")
@click.option("--sort", multiple=False, help="Sort order", type=str)
def get_contributor_collections_list(**kwargs):
    """
    List contributors' collections
    """

    get(
        url="/v2/contributors/" + kwargs["contributor_id"] + "/collections",
        params=kwargs,
        json_data=None,
    )


contributors.add_command(get_contributor_collections_list)


@click.command()
@click.argument("contributor-id")
@click.argument("id")
def get_contributor_collections(**kwargs):
    """
    Get details about contributors' collections
    """

    get(
        url="/v2/contributors/"
        + kwargs["contributor_id"]
        + "/collections/"
        + kwargs["id"]
        + "",
        params=kwargs,
        json_data=None,
    )


contributors.add_command(get_contributor_collections)


@click.command()
@click.argument("contributor-id")
@click.argument("id")
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option("--sort", multiple=False, help="Sort order", type=str)
def get_contributor_collection_items(**kwargs):
    """
    Get the items in contributors' collections
    """

    get(
        url="/v2/contributors/"
        + kwargs["contributor_id"]
        + "/collections/"
        + kwargs["id"]
        + "/items",
        params=kwargs,
        json_data=None,
    )


contributors.add_command(get_contributor_collection_items)



""""
HTTP functions.
"""

import json
import os

import requests

from .prettyprint import pretty_print
from .request_helper import RequestHelper

COLORIZE_OUTPUT = os.getenv("SHUTTERSTOCK_CLI_COLORIZE_OUTPUT")


def get(url, params, json_data=None):
    """
    Get resource.
    :param url: URL of the endpoint.
    :param params: Request parameters.
    :param json_data: Request body.
    :return: None
    """
    req = RequestHelper()
    res = requests.get(
        url=f"{req.base_endpoint}{url}",
        params=params,
        headers=req.headers,
        auth=req.auth,
    )
    try:
        if not COLORIZE_OUTPUT:
            print(json.dumps(res.json(), indent=4))
            return
        pretty_print(res.json())
    except json.decoder.JSONDecodeError:
        print(res.content)


def post(url, params, json_data):
    """
    Post resource.
    :param url: URL of the endpoint.
    :param params: Request parameters.
    :param json_data: Request body.
    :return: None
    """
    req = RequestHelper()
    res = requests.post(
        url=f"{req.base_endpoint}{url}",
        params=params,
        json=json_data,
        headers=req.headers,
        auth=req.auth,
    )
    try:
        if not COLORIZE_OUTPUT:
            print(json.dumps(res.json(), indent=4))
            return
        pretty_print(res.json())
    except json.decoder.JSONDecodeError:
        print(res.content)


def delete(url, params, json_data):
    """
    Delete resource.
    :param url: URL of the endpoint.
    :param params: Request parameters.
    :param json_data: Request body.
    :return: None
    """
    req = RequestHelper()
    res = requests.delete(
        url=f"{req.base_endpoint}{url}",
        params=params,
        json=json_data,
        headers=req.headers,
        auth=req.auth,
    )
    try:
        if not COLORIZE_OUTPUT:
            print(json.dumps(res.json(), indent=4))
            return
        pretty_print(res.json())
    except json.decoder.JSONDecodeError:
        print(res.content)


def put(url, params, json_data):
    """
    Put resource.
    :param url: URL of the endpoint.
    :param params: Request parameters.
    :param json_data: Request body.
    :return: None
    """
    req = RequestHelper()
    res = requests.put(
        url=f"{req.base_endpoint}{url}",
        params=params,
        json=json_data,
        headers=req.headers,
        auth=req.auth,
    )
    try:
        if not COLORIZE_OUTPUT:
            print(json.dumps(res.json(), indent=4))
            return
        pretty_print(res.json())
    except json.decoder.JSONDecodeError:
        print(res.content)


def patch(url, params, json_data):
    """
    PATCH resource.
    :param url: URL of the endpoint.
    :param params: Request parameters.
    :param json_data: Request body.
    :return: None
    """
    req = RequestHelper()
    res = requests.patch(
        url=f"{req.base_endpoint}{url}",
        params=params,
        json=json_data,
        headers=req.headers,
        auth=req.auth,
    )
    try:
        if not COLORIZE_OUTPUT:
            print(json.dumps(res.json(), indent=4))
            return
        pretty_print(res.json())
    except json.decoder.JSONDecodeError:
        print(res.content)



"""
test commands.
"""

import json
import click

from .utils.request import delete, get, post, patch


@click.group()
def test():
    """
    test group.
    """


@click.command()
@click.option("--text", multiple=False, help="Text to echo", type=str)
def echo(**kwargs):
    """
    Echo text
    """

    get(url="/v2/test", params=kwargs, json_data=None)


test.add_command(echo)


@click.command()
@click.option("--id", multiple=False, help="Integer ID", type=int)
@click.option("--tag", multiple=True, help="List of tags", type=str)
def validate(**kwargs):
    """
    Validate input
    """

    get(url="/v2/test/validate", params=kwargs, json_data=None)


test.add_command(validate)



"""
audio commands.
"""

import json
import click

from .utils.request import delete, get, post, patch


@click.group()
def audio():
    """
    audio group.
    """


@click.command()
@click.option(
    "--artists",
    multiple=True,
    help="Show tracks with one of the specified artist names or IDs",
    type=str,
)
@click.option(
    "--bpm",
    multiple=False,
    help=(
        "(Deprecated; use bpm_from and bpm_to instead) Show tracks with the specified"
        " beats per minute"
    ),
    type=int,
)
@click.option(
    "--bpm-from",
    multiple=False,
    help="Show tracks with the specified beats per minute or faster",
    type=int,
)
@click.option(
    "--bpm-to",
    multiple=False,
    help="Show tracks with the specified beats per minute or slower",
    type=int,
)
@click.option(
    "--duration",
    multiple=False,
    help="Show tracks with the specified duration in seconds",
    type=int,
)
@click.option(
    "--duration-from",
    multiple=False,
    help="Show tracks with the specified duration or longer in seconds",
    type=int,
)
@click.option(
    "--duration-to",
    multiple=False,
    help="Show tracks with the specified duration or shorter in seconds",
    type=int,
)
@click.option(
    "--genre",
    multiple=True,
    help=(
        "Show tracks with each of the specified genres; to get the list of genres, use"
        " `GET /v2/audio/genres`"
    ),
    type=str,
)
@click.option(
    "--is-instrumental", multiple=False, help="Show instrumental music only", type=str
)
@click.option(
    "--instruments",
    multiple=True,
    help=(
        "Show tracks with each of the specified instruments; to get the list of"
        " instruments, use `GET /v2/audio/instruments`"
    ),
    type=str,
)
@click.option(
    "--moods",
    multiple=True,
    help=(
        "Show tracks with each of the specified moods; to get the list of moods, use"
        " `GET /v2/audio/moods`"
    ),
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--query",
    multiple=False,
    help="One or more search terms separated by spaces",
    type=str,
)
@click.option("--sort", multiple=False, help="Sort by", type=str)
@click.option("--sort-order", multiple=False, help="Sort order", type=str)
@click.option(
    "--vocal-description",
    multiple=False,
    help="Show tracks with the specified vocal description (male, female)",
    type=str,
)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
@click.option(
    "--fields",
    multiple=False,
    help=(
        "Fields to display in the response; see the documentation for the fields"
        " parameter in the overview section"
    ),
    type=str,
)
@click.option("--library", multiple=False, help="Which library to search", type=str)
@click.option(
    "--language", multiple=False, help="Which language to search in", type=str
)
def search_tracks(**kwargs):
    """
    Search for tracks
    """

    get(url="/v2/audio/search", params=kwargs, json_data=None)


audio.add_command(search_tracks)


@click.command()
@click.option(
    "--language",
    multiple=False,
    help="Which language the genres will be returned",
    type=str,
)
def list_genres(**kwargs):
    """
    List audio genres
    """

    get(url="/v2/audio/genres", params=kwargs, json_data=None)


audio.add_command(list_genres)


@click.command()
def list_instruments(**kwargs):
    """
    List audio instruments
    """

    get(url="/v2/audio/instruments", params=kwargs, json_data=None)


audio.add_command(list_instruments)


@click.command()
def list_moods(**kwargs):
    """
    List audio moods
    """

    get(url="/v2/audio/moods", params=kwargs, json_data=None)


audio.add_command(list_moods)


@click.command()
@click.option("--id", multiple=True, help="One or more audio IDs", type=str)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def get_track_list(**kwargs):
    """
    List audio tracks
    """

    get(url="/v2/audio", params=kwargs, json_data=None)


audio.add_command(get_track_list)


@click.command()
@click.argument("id")
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def get_track(**kwargs):
    """
    Get details about audio tracks
    """

    get(url="/v2/audio/" + kwargs["id"] + "", params=kwargs, json_data=None)


audio.add_command(get_track)


@click.command()
@click.option("--license", multiple=False, help="License type", type=str)
@click.option(
    "--search-id",
    multiple=False,
    help="The ID of the search that led to licensing this track",
    type=str,
)
@click.argument("data")
def license_track(**kwargs):
    """
    License audio tracks
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/audio/licenses", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


audio.add_command(license_track)


@click.command()
@click.option(
    "--audio-id",
    multiple=False,
    help="Show licenses for the specified track ID",
    type=str,
)
@click.option(
    "--license",
    multiple=False,
    help=(
        "Restrict results by license. Prepending a `-` sign will exclude results by"
        " license"
    ),
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option("--sort", multiple=False, help="Sort order", type=str)
@click.option(
    "--username",
    multiple=False,
    help="Filter licenses by username of licensee",
    type=str,
)
@click.option(
    "--start-date",
    multiple=False,
    help="Show licenses created on or after the specified date",
    type=str,
)
@click.option(
    "--end-date",
    multiple=False,
    help="Show licenses created before the specified date",
    type=str,
)
@click.option(
    "--download-availability",
    multiple=False,
    help="Filter licenses by download availability",
    type=str,
)
def get_track_license_list(**kwargs):
    """
    List audio licenses
    """

    get(url="/v2/audio/licenses", params=kwargs, json_data=None)


audio.add_command(get_track_license_list)


@click.command()
@click.argument("id")
def download_tracks(**kwargs):
    """
    Download audio tracks
    """

    post(
        url="/v2/audio/licenses/" + kwargs["id"] + "/downloads",
        params=kwargs,
        json_data=None,
    )


audio.add_command(download_tracks)


@click.command()
@click.argument("data")
def create_track_collection(**kwargs):
    """
    Create audio collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/audio/collections", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


audio.add_command(create_track_collection)


@click.command()
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--embed",
    multiple=True,
    help=(
        "Which sharing information to include in the response, such as a URL to the"
        " collection"
    ),
    type=str,
)
def get_track_collection_list(**kwargs):
    """
    List audio collections
    """

    get(url="/v2/audio/collections", params=kwargs, json_data=None)


audio.add_command(get_track_collection_list)


@click.command()
@click.argument("id")
@click.option(
    "--embed",
    multiple=True,
    help=(
        "Which sharing information to include in the response, such as a URL to the"
        " collection"
    ),
    type=str,
)
@click.option(
    "--share-code",
    multiple=False,
    help="Code to retrieve a shared collection",
    type=str,
)
def get_track_collection(**kwargs):
    """
    Get the details of audio collections
    """

    get(url="/v2/audio/collections/" + kwargs["id"] + "", params=kwargs, json_data=None)


audio.add_command(get_track_collection)


@click.command()
@click.argument("id")
@click.argument("data")
def rename_track_collection(**kwargs):
    """
    Rename audio collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(
            url="/v2/audio/collections/" + kwargs["id"] + "",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


audio.add_command(rename_track_collection)


@click.command()
@click.argument("id")
def delete_track_collection(**kwargs):
    """
    Delete audio collections
    """

    delete(
        url="/v2/audio/collections/" + kwargs["id"] + "", params=kwargs, json_data=None
    )


audio.add_command(delete_track_collection)


@click.command()
@click.argument("id")
@click.argument("data")
def add_track_collection_items(**kwargs):
    """
    Add audio tracks to collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(
            url="/v2/audio/collections/" + kwargs["id"] + "/items",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


audio.add_command(add_track_collection_items)


@click.command()
@click.argument("id")
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--share-code",
    multiple=False,
    help="Code to retrieve the contents of a shared collection",
    type=str,
)
@click.option("--sort", multiple=False, help="Sort order", type=str)
def get_track_collection_items(**kwargs):
    """
    Get the contents of audio collections
    """

    get(
        url="/v2/audio/collections/" + kwargs["id"] + "/items",
        params=kwargs,
        json_data=None,
    )


audio.add_command(get_track_collection_items)


@click.command()
@click.argument("id")
@click.option(
    "--item-id",
    multiple=True,
    help="One or more item IDs to remove from the collection",
    type=str,
)
def delete_track_collection_items(**kwargs):
    """
    Remove audio tracks from collections
    """

    delete(
        url="/v2/audio/collections/" + kwargs["id"] + "/items",
        params=kwargs,
        json_data=None,
    )


audio.add_command(delete_track_collection_items)



"""
images commands.
"""

import json
import click

from .utils.request import delete, get, post, patch


@click.group()
def images():
    """
    images group.
    """


@click.command()
@click.option(
    "--added-date",
    multiple=False,
    help="Show images added on the specified date",
    type=str,
)
@click.option(
    "--added-date-start",
    multiple=False,
    help="Show images added on or after the specified date",
    type=str,
)
@click.option(
    "--aspect-ratio-min",
    multiple=False,
    help=(
        "Show images with the specified aspect ratio or higher, using a positive"
        " decimal of the width divided by the height, such as 1.7778 for a 16:9 image"
    ),
    type=float,
)
@click.option(
    "--aspect-ratio-max",
    multiple=False,
    help=(
        "Show images with the specified aspect ratio or lower, using a positive decimal"
        " of the width divided by the height, such as 1.7778 for a 16:9 image"
    ),
    type=float,
)
@click.option(
    "--aspect-ratio",
    multiple=False,
    help=(
        "Show images with the specified aspect ratio, using a positive decimal of the"
        " width divided by the height, such as 1.7778 for a 16:9 image"
    ),
    type=float,
)
@click.option(
    "--added-date-end",
    multiple=False,
    help="Show images added before the specified date",
    type=str,
)
@click.option(
    "--category",
    multiple=False,
    help=(
        "Show images with the specified Shutterstock-defined category; specify a"
        " category name or ID"
    ),
    type=str,
)
@click.option(
    "--color",
    multiple=False,
    help=(
        "Specify either a hexadecimal color in the format '4F21EA' or 'grayscale'; the"
        " API returns images that use similar colors"
    ),
    type=str,
)
@click.option(
    "--contributor",
    multiple=True,
    help="Show images with the specified contributor names or IDs, allows multiple",
    type=str,
)
@click.option(
    "--contributor-country",
    multiple=False,
    help=(
        "Show images from contributors in one or more specified countries, or start"
        " with NOT to exclude a country from the search"
    ),
    type=str,
)
@click.option(
    "--fields",
    multiple=False,
    help=(
        "Fields to display in the response; see the documentation for the fields"
        " parameter in the overview section"
    ),
    type=str,
)
@click.option(
    "--height",
    multiple=False,
    help=(
        "(Deprecated; use height_from and height_to instead) Show images with the"
        " specified height"
    ),
    type=int,
)
@click.option(
    "--height-from",
    multiple=False,
    help="Show images with the specified height or larger, in pixels",
    type=int,
)
@click.option(
    "--height-to",
    multiple=False,
    help="Show images with the specified height or smaller, in pixels",
    type=int,
)
@click.option(
    "--image-type", multiple=True, help="Show images of the specified type", type=str
)
@click.option(
    "--keyword-safe-search",
    multiple=False,
    help="Hide results with potentially unsafe keywords",
    type=str,
)
@click.option(
    "--language",
    multiple=False,
    help="Set query and result language (uses Accept-Language header if not set)",
    type=str,
)
@click.option(
    "--license",
    multiple=True,
    help="Show only images with the specified license",
    type=str,
)
@click.option(
    "--model",
    multiple=True,
    help="Show image results with the specified model IDs",
    type=str,
)
@click.option(
    "--orientation",
    multiple=False,
    help="Show image results with horizontal or vertical orientation",
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--people-model-released",
    multiple=False,
    help="Show images of people with a signed model release",
    type=str,
)
@click.option(
    "--people-age",
    multiple=False,
    help="Show images that feature people of the specified age category",
    type=str,
)
@click.option(
    "--people-ethnicity",
    multiple=True,
    help=(
        "Show images with people of the specified ethnicities, or start with NOT to"
        " show images without those ethnicities"
    ),
    type=str,
)
@click.option(
    "--people-gender",
    multiple=False,
    help="Show images with people of the specified gender",
    type=str,
)
@click.option(
    "--people-number",
    multiple=False,
    help="Show images with the specified number of people",
    type=int,
)
@click.option(
    "--query",
    multiple=False,
    help=(
        "One or more search terms separated by spaces; you can use NOT to filter out"
        " images that match a term"
    ),
    type=str,
)
@click.option(
    "--region",
    multiple=False,
    help=(
        "Raise or lower search result rankings based on the result's relevance to a"
        " specified region; you can provide a country code or an IP address from which"
        " the API infers a country"
    ),
    type=str,
)
@click.option("--safe", multiple=False, help="Enable or disable safe search", type=str)
@click.option("--sort", multiple=False, help="Sort by", type=str)
@click.option(
    "--spellcheck-query",
    multiple=False,
    help="Spellcheck the search query and return results on suggested spellings",
    type=str,
)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
@click.option(
    "--width",
    multiple=False,
    help=(
        "(Deprecated; use width_from and width_to instead) Show images with the"
        " specified width"
    ),
    type=int,
)
@click.option(
    "--width-from",
    multiple=False,
    help="Show images with the specified width or larger, in pixels",
    type=int,
)
@click.option(
    "--width-to",
    multiple=False,
    help="Show images with the specified width or smaller, in pixels",
    type=int,
)
def search_images(**kwargs):
    """
    Search for images
    """

    get(url="/v2/images/search", params=kwargs, json_data=None)


images.add_command(search_images)


@click.command()
@click.option(
    "--query",
    multiple=False,
    help="Search term for which you want keyword suggestions",
    type=str,
)
@click.option(
    "--limit", multiple=False, help="Limit the number of suggestions", type=int
)
def get_image_suggestions(**kwargs):
    """
    Get suggestions for a search term
    """

    get(url="/v2/images/search/suggestions", params=kwargs, json_data=None)


images.add_command(get_image_suggestions)


@click.command()
@click.argument("data")
def get_image_keyword_suggestions(**kwargs):
    """
    Get keywords from text
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/images/search/suggestions", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


images.add_command(get_image_keyword_suggestions)


@click.command()
@click.argument("id")
@click.option(
    "--language",
    multiple=False,
    help="Language for the keywords and categories in the response",
    type=str,
)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def get_image(**kwargs):
    """
    Get details about images
    """

    get(url="/v2/images/" + kwargs["id"] + "", params=kwargs, json_data=None)


images.add_command(get_image)


@click.command()
@click.option(
    "--language",
    multiple=False,
    help="Language for the keywords and categories in the response",
    type=str,
)
def list_image_categories(**kwargs):
    """
    List image categories
    """

    get(url="/v2/images/categories", params=kwargs, json_data=None)


images.add_command(list_image_categories)


@click.command()
@click.argument("id")
@click.option(
    "--language",
    multiple=False,
    help="Language for the keywords and categories in the response",
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def get_similar_images(**kwargs):
    """
    List similar images
    """

    get(url="/v2/images/" + kwargs["id"] + "/similar", params=kwargs, json_data=None)


images.add_command(get_similar_images)


@click.command()
@click.option(
    "--subscription-id",
    multiple=False,
    help="Subscription ID to use to license the image",
    type=str,
)
@click.option("--format", multiple=False, help="Image format", type=str)
@click.option("--size", multiple=False, help="Image size", type=str)
@click.option(
    "--search-id",
    multiple=False,
    help="Search ID that was provided in the results of an image search",
    type=str,
)
@click.argument("data")
def license_images(**kwargs):
    """
    License images
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/images/licenses", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


images.add_command(license_images)


@click.command()
@click.option(
    "--image-id",
    multiple=False,
    help="Show licenses for the specified image ID",
    type=str,
)
@click.option(
    "--license",
    multiple=False,
    help=(
        "Show images that are available with the specified license, such as `standard`"
        " or `enhanced`; prepending a `-` sign excludes results from that license"
    ),
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option("--sort", multiple=False, help="Sort order", type=str)
@click.option(
    "--username",
    multiple=False,
    help="Filter licenses by username of licensee",
    type=str,
)
@click.option(
    "--start-date",
    multiple=False,
    help="Show licenses created on or after the specified date",
    type=str,
)
@click.option(
    "--end-date",
    multiple=False,
    help="Show licenses created before the specified date",
    type=str,
)
@click.option(
    "--download-availability",
    multiple=False,
    help="Filter licenses by download availability",
    type=str,
)
def get_image_license_list(**kwargs):
    """
    List image licenses
    """

    get(url="/v2/images/licenses", params=kwargs, json_data=None)


images.add_command(get_image_license_list)


@click.command()
@click.argument("id")
@click.argument("data")
def download_image(**kwargs):
    """
    Download images
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(
            url="/v2/images/licenses/" + kwargs["id"] + "/downloads",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


images.add_command(download_image)


@click.command()
@click.option("--id", multiple=True, help="Image IDs", type=str)
@click.option(
    "--max-items",
    multiple=False,
    help="Maximum number of results returned in the response",
    type=int,
)
@click.option(
    "--safe", multiple=False, help="Restrict results to safe images", type=str
)
def get_image_recommendations(**kwargs):
    """
    List recommended images
    """

    get(url="/v2/images/recommendations", params=kwargs, json_data=None)


images.add_command(get_image_recommendations)


@click.command()
@click.argument("data")
def create_image_collection(**kwargs):
    """
    Create image collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/images/collections", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


images.add_command(create_image_collection)


@click.command()
@click.option(
    "--embed",
    multiple=True,
    help=(
        "Which sharing information to include in the response, such as a URL to the"
        " collection"
    ),
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
def get_image_collection_list(**kwargs):
    """
    List image collections
    """

    get(url="/v2/images/collections", params=kwargs, json_data=None)


images.add_command(get_image_collection_list)


@click.command()
@click.argument("id")
@click.option(
    "--embed",
    multiple=True,
    help=(
        "Which sharing information to include in the response, such as a URL to the"
        " collection"
    ),
    type=str,
)
@click.option(
    "--share-code",
    multiple=False,
    help="Code to retrieve a shared collection",
    type=str,
)
def get_image_collection(**kwargs):
    """
    Get the details of image collections
    """

    get(
        url="/v2/images/collections/" + kwargs["id"] + "", params=kwargs, json_data=None
    )


images.add_command(get_image_collection)


@click.command()
@click.argument("id")
@click.argument("data")
def rename_image_collection(**kwargs):
    """
    Rename image collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(
            url="/v2/images/collections/" + kwargs["id"] + "",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


images.add_command(rename_image_collection)


@click.command()
@click.argument("id")
def delete_image_collection(**kwargs):
    """
    Delete image collections
    """

    delete(
        url="/v2/images/collections/" + kwargs["id"] + "", params=kwargs, json_data=None
    )


images.add_command(delete_image_collection)


@click.command()
@click.argument("id")
@click.argument("data")
def add_image_collection_items(**kwargs):
    """
    Add images to collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(
            url="/v2/images/collections/" + kwargs["id"] + "/items",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


images.add_command(add_image_collection_items)


@click.command()
@click.argument("id")
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--share-code",
    multiple=False,
    help="Code to retrieve the contents of a shared collection",
    type=str,
)
@click.option("--sort", multiple=False, help="Sort order", type=str)
def get_image_collection_items(**kwargs):
    """
    Get the contents of image collections
    """

    get(
        url="/v2/images/collections/" + kwargs["id"] + "/items",
        params=kwargs,
        json_data=None,
    )


images.add_command(get_image_collection_items)


@click.command()
@click.argument("id")
@click.option(
    "--item-id",
    multiple=True,
    help="One or more image IDs to remove from the collection",
    type=str,
)
def delete_image_collection_items(**kwargs):
    """
    Remove images from collections
    """

    delete(
        url="/v2/images/collections/" + kwargs["id"] + "/items",
        params=kwargs,
        json_data=None,
    )


images.add_command(delete_image_collection_items)


@click.command()
@click.option(
    "--embed",
    multiple=False,
    help=(
        "Which sharing information to include in the response, such as a URL to the"
        " collection"
    ),
    type=str,
)
@click.option(
    "--type", multiple=True, help="The types of collections to return", type=str
)
@click.option("--asset-hint", multiple=False, help="Cover image size", type=str)
def get_featured_image_collection_list(**kwargs):
    """
    List featured image collections
    """

    get(url="/v2/images/collections/featured", params=kwargs, json_data=None)


images.add_command(get_featured_image_collection_list)


@click.command()
@click.argument("id")
@click.option(
    "--embed",
    multiple=False,
    help=(
        "Which sharing information to include in the response, such as a URL to the"
        " collection"
    ),
    type=str,
)
@click.option("--asset-hint", multiple=False, help="Cover image size", type=str)
def get_featured_image_collection(**kwargs):
    """
    Get the details of featured image collections
    """

    get(
        url="/v2/images/collections/featured/" + kwargs["id"] + "",
        params=kwargs,
        json_data=None,
    )


images.add_command(get_featured_image_collection)


@click.command()
@click.argument("id")
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
def get_featured_image_collection_items(**kwargs):
    """
    Get the contents of featured image collections
    """

    get(
        url="/v2/images/collections/featured/" + kwargs["id"] + "/items",
        params=kwargs,
        json_data=None,
    )


images.add_command(get_featured_image_collection_items)


@click.command()
@click.option(
    "--type",
    multiple=True,
    help=(
        "Show images that were added, deleted, or edited; by default, the endpoint"
        " returns images that were updated in any of these ways"
    ),
    type=str,
)
@click.option(
    "--start-date",
    multiple=False,
    help="Show images updated on or after the specified date",
    type=str,
)
@click.option(
    "--end-date",
    multiple=False,
    help="Show images updated before the specified date",
    type=str,
)
@click.option(
    "--interval",
    multiple=False,
    help=(
        "Show images updated in the specified time period, where the time period is an"
        " interval (like SQL INTERVAL) such as 1 DAY, 6 HOUR, or 30 MINUTE; the default"
        " is 1 HOUR, which shows images that were updated in the hour preceding the"
        " request"
    ),
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option("--sort", multiple=False, help="Sort order", type=str)
def get_updated_images(**kwargs):
    """
    List updated images
    """

    get(url="/v2/images/updated", params=kwargs, json_data=None)


images.add_command(get_updated_images)


@click.command()
@click.option("--id", multiple=True, help="One or more image IDs", type=str)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def get_image_list(**kwargs):
    """
    List images
    """

    get(url="/v2/images", params=kwargs, json_data=None)


images.add_command(get_image_list)



"""
cv commands.
"""

import json
import click

from .utils.request import delete, get, post, patch


@click.group()
def cv():
    """
    cv group.
    """


@click.command()
@click.argument("data")
def upload_image(**kwargs):
    """
    Upload images
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/cv/images", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


cv.add_command(upload_image)


@click.command()
@click.option(
    "--asset-id",
    multiple=False,
    help="The asset ID or upload ID to find similar images for",
    type=str,
)
@click.option(
    "--license",
    multiple=True,
    help="Show only images with the specified license",
    type=str,
)
@click.option("--safe", multiple=False, help="Enable or disable safe search", type=str)
@click.option(
    "--language",
    multiple=False,
    help="Language for the keywords and categories in the response",
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def get_similar_images(**kwargs):
    """
    List similar images
    """

    get(url="/v2/cv/similar/images", params=kwargs, json_data=None)


cv.add_command(get_similar_images)


@click.command()
@click.option(
    "--asset-id",
    multiple=False,
    help="The asset ID or upload ID to find similar videos for",
    type=str,
)
@click.option(
    "--license",
    multiple=True,
    help="Show only videos with the specified license",
    type=str,
)
@click.option("--safe", multiple=False, help="Enable or disable safe search", type=str)
@click.option(
    "--language",
    multiple=False,
    help="Language for the keywords and categories in the response",
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def get_similar_videos(**kwargs):
    """
    List similar videos
    """

    get(url="/v2/cv/similar/videos", params=kwargs, json_data=None)


cv.add_command(get_similar_videos)


@click.command()
@click.option(
    "--asset-id",
    multiple=False,
    help="The asset ID or upload ID to suggest keywords for",
    type=str,
)
def get_keywords(**kwargs):
    """
    List suggested keywords
    """

    get(url="/v2/cv/keywords", params=kwargs, json_data=None)


cv.add_command(get_keywords)



""""
Request Helper.
"""

import os

from requests.auth import HTTPBasicAuth


class RequestHelper:
    """
    Request helper class.
    """

    def __init__(self):

        self.key = os.getenv("SHUTTERSTOCK_KEY")
        self.secret = os.getenv("SHUTTERSTOCK_SECRET")
        self.token = os.getenv("SHUTTERSTOCK_API_TOKEN")
        self.sandbox_mode = (
            True if os.getenv("SHUTTERSTOCK_SANDBOX") == "true" else False
        )
        self.custom_url = os.getenv("SHUTTERSTOCK_CUSTOM_URL")

        self._auth = None
        self._headers = {"User-Agent": "Shutterstock-CLI"}

        if self.token:
            self._headers.update({"Authorization": f"Bearer {self.token}"})

        elif self.key and self.secret:
            self._auth = HTTPBasicAuth(self.key, self.secret)

    @property
    def headers(self):
        """
        :return: Dict
        """
        return self._headers

    @property
    def auth(self):
        """
        :return: HTTPBasicAuth if key and secret is set, otherwise None.
        """
        return self._auth

    @property
    def base_endpoint(self):
        """
        :return: str
        """
        if self.sandbox_mode:
            return "https://api-sandbox.shutterstock.com"

        if self.custom_url is not None:
            return self.custom_url

        return "https://api.shutterstock.com"



"""
catalog commands.
"""

import json
import click

from .utils.request import delete, get, post, patch


@click.group()
def catalog():
    """
    catalog group.
    """


@click.command()
@click.option("--sort", multiple=False, help="Sort by", type=str)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--query",
    multiple=False,
    help="One or more search terms separated by spaces",
    type=str,
)
@click.option(
    "--collection-id", multiple=True, help="Filter by collection id", type=str
)
@click.option("--asset-type", multiple=True, help="Filter by asset type", type=str)
def search_catalog(**kwargs):
    """
    Search catalogs for assets
    """

    get(url="/v2/catalog/search", params=kwargs, json_data=None)


catalog.add_command(search_catalog)


@click.command()
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option("--sort", multiple=False, help="Sort by", type=str)
def get_collections(**kwargs):
    """
    List catalog collections
    """

    get(url="/v2/catalog/collections", params=kwargs, json_data=None)


catalog.add_command(get_collections)


@click.command()
@click.argument("data")
def create_collection(**kwargs):
    """
    Create catalog collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/catalog/collections", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


catalog.add_command(create_collection)


@click.command()
@click.argument("collection-id")
@click.argument("data")
def update_collection(**kwargs):
    """
    Update collection metadata
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        patch(
            url="/v2/catalog/collections/" + kwargs["collection_id"] + "",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


catalog.add_command(update_collection)


@click.command()
@click.argument("collection-id")
def delete_collection(**kwargs):
    """
    Delete catalog collections
    """

    delete(
        url="/v2/catalog/collections/" + kwargs["collection_id"] + "",
        params=kwargs,
        json_data=None,
    )


catalog.add_command(delete_collection)


@click.command()
@click.argument("collection-id")
@click.argument("data")
def add_to_collection(**kwargs):
    """
    Add items to catalog collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(
            url="/v2/catalog/collections/" + kwargs["collection_id"] + "/items",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


catalog.add_command(add_to_collection)


@click.command()
@click.argument("collection-id")
@click.argument("data")
def delete_from_collection(**kwargs):
    """
    Remove items from catalog collection
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        delete(
            url="/v2/catalog/collections/" + kwargs["collection_id"] + "/items",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


catalog.add_command(delete_from_collection)



"""
ai_audio commands.
"""

import json
import click

from .utils.request import delete, get, post, patch


@click.group()
def ai_audio():
    """
    ai_audio group.
    """


@click.command()
@click.argument("data")
def create_audio_renders(**kwargs):
    """
    Create rendered audio
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/ai/audio/renders", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


ai_audio.add_command(create_audio_renders)


@click.command()
@click.option("--id", multiple=True, help="One or more render IDs", type=str)
def fetch_renders(**kwargs):
    """
    Get details about audio renders
    """

    get(url="/v2/ai/audio/renders", params=kwargs, json_data=None)


ai_audio.add_command(fetch_renders)


@click.command()
@click.option(
    "--id", multiple=True, help="Show instruments with the specified ID", type=str
)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option(
    "--name",
    multiple=False,
    help="Show instruments with the specified name (case-sensitive)",
    type=str,
)
@click.option(
    "--tag",
    multiple=False,
    help=(
        "Show instruments with the specified tag, such as Percussion or Strings"
        " (case-sensitive)"
    ),
    type=str,
)
def list_custom_instruments(**kwargs):
    """
    List computer audio instruments
    """

    get(url="/v2/ai/audio/instruments", params=kwargs, json_data=None)


ai_audio.add_command(list_custom_instruments)


@click.command()
@click.option(
    "--render-speed-over",
    multiple=False,
    help=(
        "Show descriptors with an average render speed that is greater than or equal to"
        " the specified value"
    ),
    type=float,
)
@click.option(
    "--band-id",
    multiple=False,
    help="Show descriptors that contain the specified band (case-sentsitive)",
    type=str,
)
@click.option(
    "--band-name",
    multiple=False,
    help="Show descriptors with the specified band name (case-sensitive)",
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--id",
    multiple=True,
    help="Show descriptors with the specified IDs (case-sensitive)",
    type=str,
)
@click.option(
    "--instrument-name",
    multiple=False,
    help="Show descriptors with the specified instrument name (case-sensitive)",
    type=str,
)
@click.option(
    "--instrument-id",
    multiple=False,
    help="Show descriptors with the specified instrument ID (case-sensitive)",
    type=str,
)
@click.option(
    "--tempo",
    multiple=False,
    help=(
        "Show descriptors whose tempo range includes the specified tempo in beats per"
        " minute"
    ),
    type=float,
)
@click.option(
    "--tempo-to",
    multiple=False,
    help=(
        "Show descriptors with a tempo that is less than or equal to the specified"
        " number"
    ),
    type=float,
)
@click.option(
    "--tempo-from",
    multiple=False,
    help=(
        "Show descriptors that have a tempo range that includes the specified tempo in"
        " beats per minute"
    ),
    type=float,
)
@click.option(
    "--name",
    multiple=False,
    help="Show descriptors with the specified name (case-sensitive)",
    type=str,
)
@click.option(
    "--tag",
    multiple=False,
    help=(
        "Show descriptors with the specified tag, such as Cinematic or Roomy"
        " (case-sensitive)"
    ),
    type=str,
)
def list_custom_descriptors(**kwargs):
    """
    List computer audio descriptors
    """

    get(url="/v2/ai/audio/descriptors", params=kwargs, json_data=None)


ai_audio.add_command(list_custom_descriptors)



"""
editorial commands.
"""

import json
import click

from .utils.request import delete, get, post, patch


@click.group()
def editorial():
    """
    editorial group.
    """


@click.command()
@click.option(
    "--query",
    multiple=False,
    help="One or more search terms separated by spaces",
    type=str,
)
@click.option("--sort", multiple=False, help="Sort by", type=str)
@click.option(
    "--category",
    multiple=False,
    help=(
        "Show editorial content within a certain editorial category; specify by"
        " category name"
    ),
    type=str,
)
@click.option(
    "--country",
    multiple=False,
    help=(
        "Show only editorial content that is available for distribution in a certain"
        " country"
    ),
    type=str,
)
@click.option(
    "--supplier-code",
    multiple=True,
    help="Show only editorial content from certain suppliers",
    type=str,
)
@click.option(
    "--date-start",
    multiple=False,
    help="Show only editorial content generated on or after a specific date",
    type=str,
)
@click.option(
    "--date-end",
    multiple=False,
    help="Show only editorial content generated on or before a specific date",
    type=str,
)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--cursor",
    multiple=False,
    help=(
        "The cursor of the page with which to start fetching results; this cursor is"
        " returned from previous requests"
    ),
    type=str,
)
def search_editorial_images(**kwargs):
    """
    Search editorial images
    """

    get(url="/v2/editorial/images/search", params=kwargs, json_data=None)


editorial.add_command(search_editorial_images)


@click.command()
def list_editorial_image_categories(**kwargs):
    """
    List editorial categories
    """

    get(url="/v2/editorial/images/categories", params=kwargs, json_data=None)


editorial.add_command(list_editorial_image_categories)


@click.command()
@click.option(
    "--type",
    multiple=False,
    help=(
        "Specify `addition` to return only images that were added or `edit` to return"
        " only images that were edited or deleted"
    ),
    type=str,
)
@click.option(
    "--date-updated-start",
    multiple=False,
    help=(
        "Show images images added, edited, or deleted after the specified date."
        " Acceptable range is 1970-01-01T00:00:01 to 2038-01-19T00:00:00."
    ),
    type=str,
)
@click.option(
    "--date-updated-end",
    multiple=False,
    help=(
        "Show images images added, edited, or deleted before the specified date."
        " Acceptable range is 1970-01-01T00:00:01 to 2038-01-19T00:00:00."
    ),
    type=str,
)
@click.option(
    "--date-taken-start",
    multiple=False,
    help=(
        "Show images that were taken on or after the specified date; use this parameter"
        " if you want recently created images from the collection instead of updated"
        " older assets"
    ),
    type=str,
)
@click.option(
    "--date-taken-end",
    multiple=False,
    help="Show images that were taken before the specified date",
    type=str,
)
@click.option(
    "--cursor",
    multiple=False,
    help=(
        "The cursor of the page with which to start fetching results; this cursor is"
        " returned from previous requests"
    ),
    type=str,
)
@click.option("--sort", multiple=False, help="Sort by", type=str)
@click.option(
    "--supplier-code",
    multiple=True,
    help="Show only editorial content from certain suppliers",
    type=str,
)
@click.option(
    "--country",
    multiple=False,
    help=(
        "Show only editorial content that is available for distribution in a certain"
        " country"
    ),
    type=str,
)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
def get_updated_editorial_images(**kwargs):
    """
    List updated content
    """

    get(url="/v2/editorial/images/updated", params=kwargs, json_data=None)


editorial.add_command(get_updated_editorial_images)


@click.command()
@click.argument("id")
@click.option(
    "--country",
    multiple=False,
    help=(
        "Returns only if the content is available for distribution in a certain country"
    ),
    type=str,
)
def get_editorial_image(**kwargs):
    """
    Get editorial content details
    """

    get(url="/v2/editorial/images/" + kwargs["id"] + "", params=kwargs, json_data=None)


editorial.add_command(get_editorial_image)


@click.command()
@click.option(
    "--image-id",
    multiple=False,
    help="Show licenses for the specified editorial image ID",
    type=str,
)
@click.option(
    "--license",
    multiple=False,
    help="Show editorial images that are available with the specified license name",
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option("--sort", multiple=False, help="Sort order", type=str)
@click.option(
    "--username",
    multiple=False,
    help="Filter licenses by username of licensee",
    type=str,
)
@click.option(
    "--start-date",
    multiple=False,
    help="Show licenses created on or after the specified date",
    type=str,
)
@click.option(
    "--end-date",
    multiple=False,
    help="Show licenses created before the specified date",
    type=str,
)
@click.option(
    "--download-availability",
    multiple=False,
    help="Filter licenses by download availability",
    type=str,
)
def get_editorial_image_license_list(**kwargs):
    """
    List editorial image licenses
    """

    get(url="/v2/editorial/images/licenses", params=kwargs, json_data=None)


editorial.add_command(get_editorial_image_license_list)


@click.command()
@click.argument("data")
def license_editorial_images(**kwargs):
    """
    License editorial content
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/editorial/images/licenses", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


editorial.add_command(license_editorial_images)


@click.command()
@click.option(
    "--country",
    multiple=False,
    help=(
        "Returns only livefeeds that are available for distribution in a certain"
        " country"
    ),
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
def get_editorial_image_livefeed_list(**kwargs):
    """
    Get editorial livefeed list
    """

    get(url="/v2/editorial/images/livefeeds", params=kwargs, json_data=None)


editorial.add_command(get_editorial_image_livefeed_list)


@click.command()
@click.argument("id")
@click.option(
    "--country",
    multiple=False,
    help=(
        "Returns only if the livefeed is available for distribution in a certain"
        " country"
    ),
    type=str,
)
def get_editorial_image_livefeed(**kwargs):
    """
    Get editorial livefeed
    """

    get(
        url="/v2/editorial/images/livefeeds/" + kwargs["id"] + "",
        params=kwargs,
        json_data=None,
    )


editorial.add_command(get_editorial_image_livefeed)


@click.command()
@click.argument("id")
@click.option(
    "--country",
    multiple=False,
    help=(
        "Returns only if the livefeed items are available for distribution in a certain"
        " country"
    ),
    type=str,
)
def get_editorial_image_livefeed_items(**kwargs):
    """
    Get editorial livefeed items
    """

    get(
        url="/v2/editorial/images/livefeeds/" + kwargs["id"] + "/items",
        params=kwargs,
        json_data=None,
    )


editorial.add_command(get_editorial_image_livefeed_items)


@click.command()
@click.option(
    "--query",
    multiple=False,
    help="One or more search terms separated by spaces",
    type=str,
)
@click.option("--sort", multiple=False, help="Sort by", type=str)
@click.option(
    "--category",
    multiple=False,
    help=(
        "Show editorial video content within a certain editorial category; specify by"
        " category name"
    ),
    type=str,
)
@click.option(
    "--country",
    multiple=False,
    help=(
        "Show only editorial video content that is available for distribution in a"
        " certain country"
    ),
    type=str,
)
@click.option(
    "--supplier-code",
    multiple=True,
    help="Show only editorial video content from certain suppliers",
    type=str,
)
@click.option(
    "--date-start",
    multiple=False,
    help="Show only editorial video content generated on or after a specific date",
    type=str,
)
@click.option(
    "--date-end",
    multiple=False,
    help="Show only editorial video content generated on or before a specific date",
    type=str,
)
@click.option(
    "--resolution",
    multiple=False,
    help="Show only editorial video content with specific resolution",
    type=str,
)
@click.option(
    "--fps",
    multiple=False,
    help="Show only editorial video content generated with specific frames per second",
    type=float,
)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--cursor",
    multiple=False,
    help=(
        "The cursor of the page with which to start fetching results; this cursor is"
        " returned from previous requests"
    ),
    type=str,
)
def search_editorial_videos(**kwargs):
    """
    Search editorial video content
    """

    get(url="/v2/editorial/videos/search", params=kwargs, json_data=None)


editorial.add_command(search_editorial_videos)


@click.command()
def list_editorial_video_categories(**kwargs):
    """
    List editorial video categories
    """

    get(url="/v2/editorial/videos/categories", params=kwargs, json_data=None)


editorial.add_command(list_editorial_video_categories)


@click.command()
@click.argument("id")
@click.option(
    "--country",
    multiple=False,
    help=(
        "Returns only if the content is available for distribution in a certain country"
    ),
    type=str,
)
def get_editorial_video(**kwargs):
    """
    Get editorial video content details
    """

    get(url="/v2/editorial/videos/" + kwargs["id"] + "", params=kwargs, json_data=None)


editorial.add_command(get_editorial_video)


@click.command()
@click.option(
    "--video-id",
    multiple=False,
    help="Show licenses for the specified editorial video ID",
    type=str,
)
@click.option(
    "--license",
    multiple=False,
    help="Show editorial videos that are available with the specified license name",
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option("--sort", multiple=False, help="Sort order", type=str)
@click.option(
    "--username",
    multiple=False,
    help="Filter licenses by username of licensee",
    type=str,
)
@click.option(
    "--start-date",
    multiple=False,
    help="Show licenses created on or after the specified date",
    type=str,
)
@click.option(
    "--end-date",
    multiple=False,
    help="Show licenses created before the specified date",
    type=str,
)
@click.option(
    "--download-availability",
    multiple=False,
    help="Filter licenses by download availability",
    type=str,
)
def get_editorial_video_license_list(**kwargs):
    """
    List editorial video licenses
    """

    get(url="/v2/editorial/videos/licenses", params=kwargs, json_data=None)


editorial.add_command(get_editorial_video_license_list)


@click.command()
@click.argument("data")
def license_editorial_video(**kwargs):
    """
    License editorial video content
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/editorial/videos/licenses", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


editorial.add_command(license_editorial_video)



"""
user commands.
"""

import json
import click

from .utils.request import delete, get, post, patch


@click.group()
def user():
    """
    user group.
    """


@click.command()
def get_user(**kwargs):
    """
    Get user details
    """

    get(url="/v2/user", params=kwargs, json_data=None)


user.add_command(get_user)


@click.command()
def get_access_token(**kwargs):
    """
    Get access token details
    """

    get(url="/v2/user/access_token", params=kwargs, json_data=None)


user.add_command(get_access_token)


@click.command()
def get_user_subscription_list(**kwargs):
    """
    List user subscriptions
    """

    get(url="/v2/user/subscriptions", params=kwargs, json_data=None)


user.add_command(get_user_subscription_list)



# -*- coding: utf-8 -*-

import os
import sys
from shutil import rmtree

from setuptools import setup, Command

with open("README.md", "rb") as input_file:
    long_descr = input_file.read().decode("utf-8")

HERE = os.path.abspath(os.path.dirname(__file__))

version_ns = {}

with open(os.path.join(HERE, "shutterstock", "__version__.py")) as input_file:
    exec(input_file.read(), {}, version_ns)


class PublishCommand(Command):
    """Support setup.py publish."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print("\033[1m{0}\033[0m".format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status("Removing previous builds…")
            rmtree(os.path.join(HERE, "dist"))
        except:
            pass

        self.status("Building Source and Wheel (universal) distribution…")
        os.system("{0} setup.py sdist bdist_wheel --universal".format(sys.executable))

        self.status("Uploading the package to PyPi via Twine…")
        os.system(
            f'twine upload dist/* -u __token__ -p {os.getenv("PYPI_TOKEN")}'
        )

        sys.exit()


setup(
    name="shutterstock-cli",
    packages=["shutterstock", "shutterstock.utils"],
    entry_points={"console_scripts": ["shutterstock = shutterstock.cli:cli"]},
    version=version_ns["__version__"],
    keywords=["shutterstock", "api", "images", "videos", "audio"],
    description="A command-line utility that allows you to interact with the Shutterstock public API.",
    long_description=long_descr,
    long_description_content_type = "text/markdown",
    author="Shutterstock",
    author_email="tech.api.team@shutterstock.com",
    url="https://github.com/shutterstock/shutterstock-cli",
    install_requires=[
        "requests",
        "click",
        "pygments",
    ],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    cmdclass={
        "publish": PublishCommand,
    },
)



"""
videos commands.
"""

import json
import click

from .utils.request import delete, get, post, patch


@click.group()
def videos():
    """
    videos group.
    """


@click.command()
@click.option(
    "--added-date",
    multiple=False,
    help="Show videos added on the specified date",
    type=str,
)
@click.option(
    "--added-date-start",
    multiple=False,
    help="Show videos added on or after the specified date",
    type=str,
)
@click.option(
    "--added-date-end",
    multiple=False,
    help="Show videos added before the specified date",
    type=str,
)
@click.option(
    "--aspect-ratio",
    multiple=False,
    help="Show videos with the specified aspect ratio",
    type=str,
)
@click.option(
    "--category",
    multiple=False,
    help=(
        "Show videos with the specified Shutterstock-defined category; specify a"
        " category name or ID"
    ),
    type=str,
)
@click.option(
    "--contributor",
    multiple=True,
    help="Show videos with the specified artist names or IDs",
    type=str,
)
@click.option(
    "--contributor-country",
    multiple=True,
    help="Show videos from contributors in one or more specified countries",
    type=str,
)
@click.option(
    "--duration",
    multiple=False,
    help=(
        "(Deprecated; use duration_from and duration_to instead) Show videos with the"
        " specified duration in seconds"
    ),
    type=int,
)
@click.option(
    "--duration-from",
    multiple=False,
    help="Show videos with the specified duration or longer in seconds",
    type=int,
)
@click.option(
    "--duration-to",
    multiple=False,
    help="Show videos with the specified duration or shorter in seconds",
    type=int,
)
@click.option(
    "--fps",
    multiple=False,
    help=(
        "(Deprecated; use fps_from and fps_to instead) Show videos with the specified"
        " frames per second"
    ),
    type=float,
)
@click.option(
    "--fps-from",
    multiple=False,
    help="Show videos with the specified frames per second or more",
    type=float,
)
@click.option(
    "--fps-to",
    multiple=False,
    help="Show videos with the specified frames per second or fewer",
    type=float,
)
@click.option(
    "--keyword-safe-search",
    multiple=False,
    help="Hide results with potentially unsafe keywords",
    type=str,
)
@click.option(
    "--language",
    multiple=False,
    help="Set query and result language (uses Accept-Language header if not set)",
    type=str,
)
@click.option(
    "--license",
    multiple=True,
    help="Show only videos with the specified license or licenses",
    type=str,
)
@click.option(
    "--model",
    multiple=True,
    help="Show videos with each of the specified models",
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--people-age",
    multiple=False,
    help="Show videos that feature people of the specified age range",
    type=str,
)
@click.option(
    "--people-ethnicity",
    multiple=True,
    help="Show videos with people of the specified ethnicities",
    type=str,
)
@click.option(
    "--people-gender",
    multiple=False,
    help="Show videos with people with the specified gender",
    type=str,
)
@click.option(
    "--people-number",
    multiple=False,
    help="Show videos with the specified number of people",
    type=int,
)
@click.option(
    "--people-model-released",
    multiple=False,
    help="Show only videos of people with a signed model release",
    type=str,
)
@click.option(
    "--query",
    multiple=False,
    help=(
        "One or more search terms separated by spaces; you can use NOT to filter out"
        " videos that match a term"
    ),
    type=str,
)
@click.option(
    "--resolution",
    multiple=False,
    help="Show videos with the specified resolution",
    type=str,
)
@click.option("--safe", multiple=False, help="Enable or disable safe search", type=str)
@click.option(
    "--sort", multiple=False, help="Sort by one of these categories", type=str
)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def search_videos(**kwargs):
    """
    Search for videos
    """

    get(url="/v2/videos/search", params=kwargs, json_data=None)


videos.add_command(search_videos)


@click.command()
@click.option(
    "--query",
    multiple=False,
    help="Search term for which you want keyword suggestions",
    type=str,
)
@click.option(
    "--limit", multiple=False, help="Limit the number of the suggestions", type=int
)
def get_video_suggestions(**kwargs):
    """
    Get suggestions for a search term
    """

    get(url="/v2/videos/search/suggestions", params=kwargs, json_data=None)


videos.add_command(get_video_suggestions)


@click.command()
@click.option("--id", multiple=True, help="One or more video IDs", type=str)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def get_video_list(**kwargs):
    """
    List videos
    """

    get(url="/v2/videos", params=kwargs, json_data=None)


videos.add_command(get_video_list)


@click.command()
@click.argument("id")
@click.option(
    "--language",
    multiple=False,
    help="Language for the keywords and categories in the response",
    type=str,
)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def get_video(**kwargs):
    """
    Get details about videos
    """

    get(url="/v2/videos/" + kwargs["id"] + "", params=kwargs, json_data=None)


videos.add_command(get_video)


@click.command()
@click.option(
    "--subscription-id",
    multiple=False,
    help="The subscription ID to use for licensing",
    type=str,
)
@click.option(
    "--size", multiple=False, help="The size of the video to license", type=str
)
@click.option(
    "--search-id",
    multiple=False,
    help="The Search ID that led to this licensing event",
    type=str,
)
@click.argument("data")
def license_videos(**kwargs):
    """
    License videos
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/videos/licenses", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


videos.add_command(license_videos)


@click.command()
@click.option(
    "--video-id",
    multiple=False,
    help="Show licenses for the specified video ID",
    type=str,
)
@click.option(
    "--license",
    multiple=False,
    help=(
        "Show videos that are available with the specified license, such as `standard`"
        " or `enhanced`; prepending a `-` sign excludes results from that license"
    ),
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--sort", multiple=False, help="Sort by oldest or newest videos first", type=str
)
@click.option(
    "--username",
    multiple=False,
    help="Filter licenses by username of licensee",
    type=str,
)
@click.option(
    "--start-date",
    multiple=False,
    help="Show licenses created on or after the specified date",
    type=str,
)
@click.option(
    "--end-date",
    multiple=False,
    help="Show licenses created before the specified date",
    type=str,
)
@click.option(
    "--download-availability",
    multiple=False,
    help="Filter licenses by download availability",
    type=str,
)
def get_video_license_list(**kwargs):
    """
    List video licenses
    """

    get(url="/v2/videos/licenses", params=kwargs, json_data=None)


videos.add_command(get_video_license_list)


@click.command()
@click.argument("id")
@click.argument("data")
def download_videos(**kwargs):
    """
    Download videos
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(
            url="/v2/videos/licenses/" + kwargs["id"] + "/downloads",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


videos.add_command(download_videos)


@click.command()
@click.argument("data")
def create_video_collection(**kwargs):
    """
    Create video collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(url="/v2/videos/collections", params=kwargs, json_data=json_data)
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


videos.add_command(create_video_collection)


@click.command()
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--embed",
    multiple=True,
    help=(
        "Which sharing information to include in the response, such as a URL to the"
        " collection"
    ),
    type=str,
)
def get_video_collection_list(**kwargs):
    """
    List video collections
    """

    get(url="/v2/videos/collections", params=kwargs, json_data=None)


videos.add_command(get_video_collection_list)


@click.command()
@click.argument("id")
@click.option(
    "--embed",
    multiple=True,
    help=(
        "Which sharing information to include in the response, such as a URL to the"
        " collection"
    ),
    type=str,
)
@click.option(
    "--share-code",
    multiple=False,
    help="Code to retrieve a shared collection",
    type=str,
)
def get_video_collection(**kwargs):
    """
    Get the details of video collections
    """

    get(
        url="/v2/videos/collections/" + kwargs["id"] + "", params=kwargs, json_data=None
    )


videos.add_command(get_video_collection)


@click.command()
@click.argument("id")
@click.argument("data")
def rename_video_collection(**kwargs):
    """
    Rename video collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(
            url="/v2/videos/collections/" + kwargs["id"] + "",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


videos.add_command(rename_video_collection)


@click.command()
@click.argument("id")
def delete_video_collection(**kwargs):
    """
    Delete video collections
    """

    delete(
        url="/v2/videos/collections/" + kwargs["id"] + "", params=kwargs, json_data=None
    )


videos.add_command(delete_video_collection)


@click.command()
@click.option(
    "--language",
    multiple=False,
    help="Language for the keywords and categories in the response",
    type=str,
)
def list_video_categories(**kwargs):
    """
    List video categories
    """

    get(url="/v2/videos/categories", params=kwargs, json_data=None)


videos.add_command(list_video_categories)


@click.command()
@click.argument("id")
@click.argument("data")
def add_video_collection_items(**kwargs):
    """
    Add videos to collections
    """

    try:
        with open(kwargs["data"], encoding="UTF-8") as input_data:
            json_data = json.load(input_data)

        post(
            url="/v2/videos/collections/" + kwargs["id"] + "/items",
            params=kwargs,
            json_data=json_data,
        )
    except json.decoder.JSONDecodeError:
        print(
            "Error loading JSON file. Please pass a valid JSON file as an argument."
            " (Check API reference for more information)"
        )


videos.add_command(add_video_collection_items)


@click.command()
@click.argument("id")
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--share-code",
    multiple=False,
    help="Code to retrieve the contents of a shared collection",
    type=str,
)
@click.option("--sort", multiple=False, help="Sort order", type=str)
def get_video_collection_items(**kwargs):
    """
    Get the contents of video collections
    """

    get(
        url="/v2/videos/collections/" + kwargs["id"] + "/items",
        params=kwargs,
        json_data=None,
    )


videos.add_command(get_video_collection_items)


@click.command()
@click.argument("id")
@click.option(
    "--item-id",
    multiple=True,
    help="One or more video IDs to remove from the collection",
    type=str,
)
def delete_video_collection_items(**kwargs):
    """
    Remove videos from collections
    """

    delete(
        url="/v2/videos/collections/" + kwargs["id"] + "/items",
        params=kwargs,
        json_data=None,
    )


videos.add_command(delete_video_collection_items)


@click.command()
@click.option(
    "--embed",
    multiple=False,
    help="What information to include in the response, such as a URL to the collection",
    type=str,
)
def get_featured_video_collection_list(**kwargs):
    """
    List featured video collections
    """

    get(url="/v2/videos/collections/featured", params=kwargs, json_data=None)


videos.add_command(get_featured_video_collection_list)


@click.command()
@click.argument("id")
@click.option(
    "--embed",
    multiple=False,
    help="What information to include in the response, such as a URL to the collection",
    type=str,
)
def get_featured_video_collection(**kwargs):
    """
    Get the details of featured video collections
    """

    get(
        url="/v2/videos/collections/featured/" + kwargs["id"] + "",
        params=kwargs,
        json_data=None,
    )


videos.add_command(get_featured_video_collection)


@click.command()
@click.argument("id")
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
def get_featured_video_collection_items(**kwargs):
    """
    Get the contents of featured video collections
    """

    get(
        url="/v2/videos/collections/featured/" + kwargs["id"] + "/items",
        params=kwargs,
        json_data=None,
    )


videos.add_command(get_featured_video_collection_items)


@click.command()
@click.argument("id")
@click.option(
    "--language",
    multiple=False,
    help="Language for the keywords and categories in the response",
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--view",
    multiple=False,
    help="Amount of detail to render in the response",
    type=str,
)
def find_similar_videos(**kwargs):
    """
    List similar videos
    """

    get(url="/v2/videos/" + kwargs["id"] + "/similar", params=kwargs, json_data=None)


videos.add_command(find_similar_videos)


@click.command()
@click.option(
    "--start-date",
    multiple=False,
    help="Show videos updated on or after the specified date",
    type=str,
)
@click.option(
    "--end-date",
    multiple=False,
    help="Show videos updated before the specified date",
    type=str,
)
@click.option(
    "--interval",
    multiple=False,
    help=(
        "Show videos updated in the specified time period, where the time period is an"
        " interval (like SQL INTERVAL) such as 1 DAY, 6 HOUR, or 30 MINUTE; the default"
        " is 1 HOUR, which shows videos that were updated in the hour preceding the"
        " request"
    ),
    type=str,
)
@click.option("--page", multiple=False, help="Page number", type=int)
@click.option("--per-page", multiple=False, help="Number of results per page", type=int)
@click.option(
    "--sort", multiple=False, help="Sort by oldest or newest videos first", type=str
)
def get_updated_videos(**kwargs):
    """
    List updated videos
    """

    get(url="/v2/videos/updated", params=kwargs, json_data=None)


videos.add_command(get_updated_videos)
